pub fn auto_detect_default_model() -> Option<&'static str>
Detect which provider has available credentials and return its default model. Returns None if no credentials are found for any provider.
None